#
# spec file for package python-icoextract
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-icoextract
Version:        0.1.4
Release:        1.8
Summary:        Extract icons from Windows PE files (.exe/.dll)
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/jlu5/icoextract
Source:         https://github.com/jlu5/icoextract/archive/%{version}/icoextract-%{version}.tar.gz
# BuildRequires:  %%{python_module devel}
BuildRequires:  %{python_module pefile}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  mingw32-cross-binutils
BuildRequires:  mingw32-cross-gcc
BuildRequires:  mingw64-cross-gcc
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires:       python-pefile
Requires(post): update-alternatives
Requires(postun):update-alternatives
Suggests:       python-Pillow
BuildArch:      noarch
%python_subpackages

%description
icoextract is an icon extractor for Windows PE files (.exe/.dll), written in
Python. It also includes a thumbnailer script (exe-thumbnailer) for Linux
desktops.

%prep
%setup -q -n icoextract-%{version}

find . -name \*.py -exec sed -i -e '1{\@^#!%{_bindir}/env python@d}' '{}' \;

%build
%pyproject_wheel

%install
%pyproject_install
mkdir -p %{buildroot}%{_datadir}/thumbnailers/
cp exe-thumbnailer.thumbnailer %{buildroot}%{_datadir}/thumbnailers/
%python_clone -a %{buildroot}%{_bindir}/exe-thumbnailer
%python_clone -a %{buildroot}%{_bindir}/icoextract
%python_clone -a %{buildroot}%{_bindir}/icolist
%python_clone -a %{buildroot}%{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd tests
%make_build
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python test_extract.py
$python test_thumbnailer.py
}

%post
update-alternatives --install \
    %{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer \
    exe-thumbnailer.thumbnailer \
    %{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer-%{python_version} %{python_version_nodots}
%python_install_alternative exe-thumbnailer
%python_install_alternative icoextract
%python_install_alternative icolist

%postun
[ -f %{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer-%{python_version} ] || update-alternatives --remove \
    exe-thumbnailer.thumbnailer \
    %{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer-%{python_version}
%python_uninstall_alternative exe-thumbnailer
%python_uninstall_alternative icoextract
%python_uninstall_alternative icolist

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/icoextract
%{python_sitelib}/icoextract-%{version}*-info
%python_alternative %{_bindir}/exe-thumbnailer
%python_alternative %{_bindir}/icoextract
%python_alternative %{_bindir}/icolist
%dir %{_datadir}/thumbnailers
%python_alternative %{_datadir}/thumbnailers/exe-thumbnailer.thumbnailer

%changelog
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to icoextract 0.1.4 (2022-08-08)
  IconExtractor: support raw bytes as input, in addition to a filename
  Refresh function descriptions
* Tue Aug 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Don't use %%{python_module FOO} on Requires/Recommends/Suggests.
* Sat Jul 16 2022 Matej Cepl <mcepl@suse.com>
- Cleanup the SPEC file.
* Sat Jul 16 2022 Imo Hester <vortex@z-ray.de>
- Clean spec file
* Sat Jul 16 2022 Imo Hester <vortex@z-ray.de>
- Fixed multi version support for exe-thumbnailer.thumbnailer
* Sat Jul 16 2022 Imo Hester <vortex@z-ray.de>
- Added %%check for provided test files
* Fri Jul 15 2022 Imo Hester <vortex@z-ray.de>
- Removed %%global module_name icoextract
- Ran spec-cleaner
* Fri Jul 15 2022 Imo Hester <vortex@z-ray.de>
- Added pefile to runtime requirements
* Fri Jul 15 2022 Imo Hester <vortex@z-ray.de>
- Removed min required python-devel version
* Fri Jul 15 2022 Imo Hester <vortex@z-ray.de>
- Proper python sitelib support
* Thu Jul 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 0.1.3
  * setup.py: exclude tests from installed packages
  * More verbose install notes
  * CI: run tests on bullseye
  * More tests for thumbnailers on various sizes
  * tests: cleanup Makefile
  * thumbnailer: use native 128x128 icons when available
  * Update supported Python versions
  * Move version check and metadata fields to setup.cfg
  * README: probably better to install icoextract[thumbnailer]
  * Add changelog
* Sun Oct 17 2021 Antônio Vinícius Menezes Medeiros <linuxkamarada@gmail.com> - 0.1.2
- Update to v0.1.2
* Sun Jul  5 2020 Antônio Vinícius Menezes Medeiros <linuxkamarada@gmail.com> - 0.1.1
- Update to v0.1.1
* Tue Feb  4 2020 Antônio Vinícius Menezes Medeiros <linuxkamarada@gmail.com> - 0.1.0
- First icoextract package
